@@ -1,8 +1,8 @@
-"""Views used by the links application."""
+'''Views used by the links application.'''
 
 from django.shortcuts import redirect
 
 
 def index(request):
-    """Redirects to a new page."""
+    '''Redirects to a new page.'''
     return redirect(request.pages.current.content.get_link_url_resolved())
