@@ -1,4 +1,4 @@
-"""Tests for the pages app."""
+'''Tests for the pages app.'''
 from datetime import timedelta
 
 from django.contrib.contenttypes.models import ContentType
@@ -10,28 +10,12 @@ from reversion import create_revision
 from watson import search
 
 from ....models.managers import publication_manager
+from ...testing_models.models import (TestSection, TestPageContent,
+                                      TestPageContentWithSections)
 from ..models import (ContentBase, Page, PageSearchAdapter, PageSitemap,
                       filter_indexable_pages)
 
 
-class TestPageContent(ContentBase):
-
-    urlconf = 'cms.apps.pages.tests.urls'
-
-
-class TestPageContentWithSections(ContentBase):
-    pass
-
-
-class Section(models.Model):
-
-    page = models.ForeignKey(Page)
-
-    title = models.CharField(
-        max_length=100,
-    )
-
-
 class TestPage(TestCase):
 
     def setUp(self):
@@ -41,7 +25,7 @@ class TestPage(TestCase):
             content_type = ContentType.objects.get_for_model(TestPageContent)
 
             self.homepage = Page.objects.create(
-                title="Homepage",
+                title='Homepage',
                 slug='homepage',
                 content_type=content_type,
             )
@@ -52,7 +36,7 @@ class TestPage(TestCase):
 
             self.section = Page.objects.create(
                 parent=self.homepage,
-                title="Section",
+                title='Section',
                 content_type=content_type,
             )
 
@@ -62,7 +46,7 @@ class TestPage(TestCase):
 
             self.subsection = Page.objects.create(
                 parent=self.section,
-                title="Subsection",
+                title='Subsection',
                 content_type=content_type,
             )
 
@@ -72,7 +56,7 @@ class TestPage(TestCase):
 
             self.subsubsection = Page.objects.create(
                 parent=self.subsection,
-                title="Subsubsection",
+                title='Subsubsection',
                 content_type=content_type,
             )
 
@@ -80,27 +64,16 @@ class TestPage(TestCase):
                 page=self.subsubsection,
             )
 
-    def testChildPrefetching(self):
-        # Make sure that prefetching works to two levels deep.
-        with self.assertNumQueries(3):
-            homepage = Page.objects.get_homepage()
-
-        with self.assertNumQueries(2):
-            subsection = homepage.children[0].children[0]
-        self.assertEqual(subsection.title, "Subsection")
-
-        with self.assertNumQueries(0):
-            subsection = homepage.navigation[0].navigation[0]
-        self.assertEqual(subsection.title, "Subsection")
-
-        # Make sure that, beyond this, it doesn't go  pathalogical.
-        with self.assertNumQueries(1):
-            subsubsection = subsection.children[0]
-        self.assertEqual(subsubsection.title, "Subsubsection")
-
-        with self.assertNumQueries(0):
-            subsubsection = subsection.children[0]
-        self.assertEqual(subsubsection.title, "Subsubsection")
+    def test_children(self):
+        homepage = Page.objects.get_homepage()
+        subsection = homepage.children[0].children[0]
+        self.assertEqual(subsection.title, 'Subsection')
+        subsection = homepage.navigation[0].navigation[0]
+        self.assertEqual(subsection.title, 'Subsection')
+        subsubsection = subsection.children[0]
+        self.assertEqual(subsubsection.title, 'Subsubsection')
+        subsubsection = subsection.children[0]
+        self.assertEqual(subsubsection.title, 'Subsubsection')
 
     def test_page_reverse(self):
         url = self.homepage.reverse('detail', kwargs={
@@ -144,15 +117,15 @@ class TestPage(TestCase):
         self.assertEqual(self.subsubsection.content.__str__(), 'Subsubsection')
 
     def test_pagesearchadapter_get_live_queryset(self):
-        self.assertEqual(len(search.search("Homepage", models=(Page,))), 1)
+        self.assertEqual(len(search.search('Homepage', models=(Page,))), 1)
 
         with publication_manager.select_published(True):
-            self.assertEqual(len(search.search("Homepage", models=(Page,))), 1)
+            self.assertEqual(len(search.search('Homepage', models=(Page,))), 1)
 
             self.homepage.is_online = False
             self.homepage.save()
 
-            self.assertEqual(len(search.search("Homepage", models=(Page,))), 0)
+            self.assertEqual(len(search.search('Homepage', models=(Page,))), 0)
 
     def test_page_get_absolute_url(self):
         with search.update_index():
@@ -166,32 +139,29 @@ class TestPage(TestCase):
                 left=None,
                 right=None,
             )
-            self.assertIsNone(new_page.cached_url)
+
             new_page.save()
-            self.assertEqual(new_page.cached_url, '/')
 
             TestPageContent.objects.create(
                 page=new_page,
             )
 
         self.assertEqual(new_page.get_absolute_url(), '/')
-        self.assertEqual(new_page.get_absolute_url(True), '/')
 
         new_page = Page.objects.get(pk=new_page.pk)
-        self.assertEqual(new_page.cached_url, '/')
         self.assertEqual(new_page.get_absolute_url(), '/')
 
     def test_last_modified(self):
 
         # We have no versions
-        self.assertEquals(self.homepage.last_modified(), '-')
+        self.assertEqual(self.homepage.last_modified(), '-')
 
         # Create an initial revision.
         with create_revision():
             self.homepage.save()
 
         # We have reversion and a version in the db, last_modified should not be empty
-        self.assertNotEquals(self.homepage.last_modified(), '-')
+        self.assertNotEqual(self.homepage.last_modified(), '-')
 
     def test_publication(self):
         self.homepage.publication_date = now() + timedelta(days=10)
@@ -225,7 +195,7 @@ class TestSectionPage(TestCase):
             content_type = ContentType.objects.get_for_model(TestPageContentWithSections)
 
             self.homepage = Page.objects.create(
-                title="Homepage",
+                title='Homepage',
                 slug='homepage',
                 content_type=content_type,
             )
@@ -238,12 +208,12 @@ class TestSectionPage(TestCase):
         search_adapter = PageSearchAdapter(Page)
 
         content = search_adapter.get_content(self.homepage)
-        self.assertEqual(content, "      homepage Homepage  / ")
+        self.assertEqual(content, '      homepage Homepage  testing')
 
 
 class TestPageComplex(TestCase):
 
-    """
+    '''
     Page structure:
 
                                   Homepage
@@ -260,7 +230,7 @@ class TestPageComplex(TestCase):
                                        |                     |
                                 Tree 3 - Page 4       Tree 3 - Page 5
 
-    """
+    '''
 
     def setUp(self):
         structure = {
