@@ -1,11 +1,12 @@
 from django.conf.urls import url
-from django.http import Http404
+from django.http import Http404, HttpResponse
 
 
 def view(request, *args, **kwargs):
     if request.path == '/raise404/':
         raise Http404
-    return None
+    return HttpResponse('Hello!')
+
 
 urlpatterns = [
     url("^$", view, name="index"),
