@@ -1,14 +1,14 @@
-"""Custom middleware used by the pages application."""
+'''Custom middleware used by the pages application.'''
 
 import re
 
 from django.conf import settings
-from django.contrib.gis.geoip import GeoIP
 from django.shortcuts import redirect
 from django.template.response import SimpleTemplateResponse
+from django.utils.deprecation import MiddlewareMixin
 
 from cms.apps.pages.models import Country
-from cms.models import PublicationManagementError, publication_manager
+from cms.models import PublicationManagementError, publication_manager, path_token_generator
 
 
 def get_client_ip(request):
@@ -20,32 +20,42 @@ def get_client_ip(request):
     return ip
 
 
-class PublicationMiddleware(object):
+class PublicationMiddleware(MiddlewareMixin):
 
-    """Middleware that enables preview mode for admin users."""
-
-    def __init__(self):
-        """Initializes the PublicationMiddleware."""
-        self.exclude_urls = [
-            re.compile(url)
-            for url in
-            getattr(settings, "PUBLICATION_MIDDLEWARE_EXCLUDE_URLS", ())
-        ]
+    '''Middleware that enables preview mode for admin users.'''
 
     def process_request(self, request):
-        """Starts preview mode, if available."""
-        if not any(pattern.match(request.path_info[1:]) for pattern in self.exclude_urls):
+        '''Starts preview mode, if available.'''
+
+        exclude_urls = [
+            re.compile(url)
+            for url in
+            getattr(settings, 'PUBLICATION_MIDDLEWARE_EXCLUDE_URLS', ())
+        ]
+
+        if not any(pattern.match(request.path_info[1:]) for pattern in exclude_urls):
             # See if preview mode is requested.
             try:
-                preview_mode = bool(int(request.GET.get("preview", 0)))
-            except ValueError:
-                preview_mode = False
-            # Only allow preview mode if the user is a logged in administrator.
-            preview_mode = preview_mode and request.user.is_authenticated() and request.user.is_staff and request.user.is_active
+                path = f'{request.path_info[1:] if request.path_info[1:] else request.path_info}'
+                # Check for the value of 'preview' matching the token for the
+                # current path. This is intended to throw KeyError if is not
+                # present.
+                token_preview_valid = path_token_generator.check_token(request.GET['preview'], path)
+                # Allow something like preview=1, preview=any_other_value if
+                # they are a staff user.
+                user_preview = request.GET['preview'] and request.user.is_staff
+            except KeyError:
+                # Preview mode was not requested.
+                user_preview = False
+                token_preview_valid = False
+
+            # Only allow preview mode if the user is a logged in administrator
+            # or they have a token for this specific path.
+            preview_mode = token_preview_valid or user_preview
             publication_manager.begin(not preview_mode)
 
     def process_response(self, request, response):
-        """Cleans up after preview mode."""
+        '''Cleans up after preview mode.'''
         # Render the response if we're in a block of publication management.
         if publication_manager.select_published_active():
             if isinstance(response, SimpleTemplateResponse):
@@ -60,7 +70,7 @@ class PublicationMiddleware(object):
         return response
 
 
-class LocalisationMiddleware(object):
+class LocalisationMiddleware(MiddlewareMixin):
 
     def process_request(self, request):
 
@@ -96,6 +106,11 @@ class LocalisationMiddleware(object):
                 pass
 
     def process_response(self, request, response, geoip_path=None):
+        # This import is here to avoid an exception being thrown when
+        # localisation is not required - this import will fail if GeoIP files
+        # are not present.
+        from django.contrib.gis.geoip2 import GeoIP2
+        from geoip2.errors import AddressNotFoundError
 
         # Continue for media
         if request.path.startswith('/media/') \
@@ -108,10 +123,16 @@ class LocalisationMiddleware(object):
         if request.country is None:
 
             # Get the Geo location of the requests IP
-            geo_ip = GeoIP(path=geoip_path)
-            country_geo_ip = geo_ip.country(get_client_ip(request))
+            geo_ip = GeoIP2(path=geoip_path)
 
-            if country_geo_ip['country_code']:
+            try:
+                country_geo_ip = geo_ip.country(get_client_ip(request))
+            except AddressNotFoundError:
+                # If no county found for that IP, just don't look for a country
+                # and go with the default
+                country_geo_ip = {}
+
+            if country_geo_ip.get('country_code'):
                 try:
                     request.country = Country.objects.get(
                         code__iexact=country_geo_ip['country_code']
