@@ -1,6 +1,4 @@
-"""Template tags for rendering pagination."""
-from __future__ import unicode_literals
-
+'''Template tags for rendering pagination.'''
 import jinja2
 from django.core.paginator import InvalidPage, Paginator
 from django.http import Http404
@@ -10,9 +8,9 @@ from django_jinja import library
 
 @library.global_function
 @jinja2.contextfunction
-def paginate(context, queryset, per_page=10, key="page"):
-    """Paginates the given queryset as sets it in the context as a variable."""
-    request = context["request"]
+def paginate(context, queryset, per_page=10, key='page'):
+    '''Returns a paginator object for the given queryset.'''
+    request = context['request']
 
     # Parse the page number.
     try:
@@ -23,7 +21,7 @@ def paginate(context, queryset, per_page=10, key="page"):
     try:
         page = Paginator(queryset, per_page).page(page_number)
     except InvalidPage:
-        raise Http404("There are no items on page {}.".format(page_number))
+        raise Http404('There are no items on page {}.'.format(page_number))
     page._pagination_key = key
 
     return page
@@ -33,26 +31,26 @@ def paginate(context, queryset, per_page=10, key="page"):
 @library.render_with('pagination/pagination.html')
 @jinja2.contextfunction
 def render_pagination(context, page_obj, pagination_key=None):
-    """Renders the pagination for the given page of items."""
+    '''Renders pagination for the given paginator object.'''
     return {
-        "request": context["request"],
-        "page_obj": page_obj,
-        "paginator": page_obj.paginator,
-        "pagination_key": pagination_key or getattr(page_obj, "_pagination_key", "page")
+        'request': context['request'],
+        'page_obj': page_obj,
+        'paginator': page_obj.paginator,
+        'pagination_key': pagination_key or getattr(page_obj, '_pagination_key', 'page')
     }
 
 
 @library.global_function
 @jinja2.contextfunction
 def get_pagination_url(context, page_number):
-    """Renders the URL for the given page number."""
-    request = context["request"]
+    '''Returns a URL for the given page number.'''
+    request = context['request']
     url = request.path
     params = request.GET.copy()
-    if str(page_number) != "1":
-        params[context.get("pagination_key", "page")] = page_number
+    if str(page_number) != '1':
+        params[context.get('pagination_key', 'page')] = page_number
     else:
-        params.pop(context.get("pagination_key", "page"), None)
+        params.pop(context.get('pagination_key', 'page'), None)
     if params:
-        url += "?%s" % params.urlencode()
+        url += '?{}'.format(params.urlencode())
     return escape(url)
